@@ -18,7 +18,6 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 import os.path
-import re
 import sys
 from PyQt4 import QtCore, QtGui
 
@@ -27,7 +26,6 @@ from bzrlib import (
     bugtracker,
     errors,
     osutils,
-    urlutils,
     )
 from bzrlib.workingtree import WorkingTree
 import bzrlib
@@ -98,7 +96,7 @@ class DirectoryItem(SideBarItem):
     def __init__(self, fileInfo, parent, sidebar):
         self.path = fileInfo.filePath()
         self.icon = QtCore.QVariant(sidebar.window.icons['folder'])
-        self.text = QtCore.QVariant(fileInfo.fileName())
+        self.text = QtCore.QVariant(fileInfo.fileName() or fileInfo.path())
         self.parent = parent
         self.children = None
 
@@ -413,7 +411,7 @@ class QBzrMainWindow(QBzrWindow):
             gettext(u"<b>QBzr</b> \u2014 A graphical user interface for Bazaar<br>"
                     u"<small>Version %(qbzr_version)s (bzrlib %(bzrlib_version)s)</small><br>"
                     u"<br>"
-                    u"Copyright \u00A9 2006-2007 Luk\xe1\u0161 Lalinsk\xfd and others<br>"
+                    u"Copyright \u00A9 2006-2008 Luk\xe1\u0161 Lalinsk\xfd and others<br>"
                     u"<br>"
                     u'<a href="http://bazaar-vcs.org/QBzr">http://bazaar-vcs.org/QBzr</a>') % tpl)
 
@@ -518,9 +516,15 @@ class QBzrMainWindow(QBzrWindow):
 
     def onFileActivated(self, item, column):
         path = item.data(0, QtCore.Qt.UserRole).toString()
-        if not path:
-            return
-        self.setDirectory(unicode(path))
+        if path:
+            # directory
+            self.setDirectory(unicode(path))
+        else:
+            # file
+            basename = unicode(item.text(0))
+            filepath = osutils.pathjoin(self.currentDirectory, basename)
+            url = QtCore.QUrl(filepath)
+            result = QtGui.QDesktopServices.openUrl(url)
 
     def refresh(self):
         if self.currentDirectory:
